@@ -4,18 +4,18 @@ in user's configuration directory.
 '''
 
 
-class Configuration:
+class ConfigurationDeprecated:
     def __init__(self):
-        self.configFileName = "config.yaml"
-        self.appName = "cashiersync"
-        self.createConfigFile()
-        self.config = self.readConfig()
+        self.config_file_name = "config.yaml"
+        self.app_name = "cashiersync"
+        self.create_config_file()
+        self.config = self.read_config()
 
-    def readConfig(self):
+    def read_config(self):
         ''' Read configuration file '''
         import yaml
 
-        path = self.getConfigPath()
+        path = self.get_config_path()
         content = ''
         with open(path, 'r') as stream:
             try:
@@ -26,40 +26,40 @@ class Configuration:
 
         return content
 
-    def createConfigFile(self):
+    def create_config_file(self):
         ''' create the config file if it does not exist '''
         import os
         # Create the config folder
-        dir = self.getConfigDir()
+        dir = self.get_config_dir()
         if not os.path.exists(dir) and not os.path.isdir(dir):
             os.makedirs(dir)
         # Create file
-        path = self.getConfigPath()
+        path = self.get_config_path()
         if os.path.exists(path):
             return
 
         with open(path, "w") as config_file:
-            content = self.getTemplate()
+            content = self.get_template()
             config_file.write(content)
 
-    def getTemplate(self):
+    def get_template(self):
         return '''# Configuration
 ledger_working_dir: .
         '''
 
     # @property
-    def getConfigDir(self):
+    def get_config_dir(self):
         from xdg.BaseDirectory import xdg_config_home
         from os.path import sep
 
-        return xdg_config_home + sep + self.appName
+        return xdg_config_home + sep + self.app_name
 
     # @property
-    def getConfigPath(self):
+    def get_config_path(self):
         ''' assembles the path to the config file '''
         from os.path import sep
 
-        return self.getConfigDir() + sep + self.configFileName
+        return self.get_config_dir() + sep + self.config_file_name
 
     @property
     def ledger_working_dir(self):
