@@ -41,4 +41,7 @@ class LedgerOutputParser:
         if total_line is None:
             raise ValueError(f'No total fetched in {output}')
 
-        return result
\ No newline at end of file
+        return result
+
+    def get_lot_lines(self, output):
+        pass
